#!/usr/bin/perl
#
#  This script fetches all quaternions and angular rates from a
#  specified TDS within specified time interval using query2plot
#  SFOC utility.
#
#  Usage:
#
#     > <this_script_name> <start> <stop> <raw_quats_file>
#
#  where <start> <stop> must be in YYYY-MM-DDTHR:MN:SC.### format.
#
$scriptname = "cas_get_quats_av_castds1.pl";
$version    = "1.0.0, February 12, 2000, BVS, NAIF/JPL";

#
#  Setups:
#
#     -- TDS name;
#     -- temporary PVL file name;
#     -- temporary channel set file name;
#     -- temporary query2plot log file name;
#
$tds        = "Cas_castds1_QueryServer";
$pvlfile    = "query2plot.pvl";
$chsfile    = "query2plot.cs";
$logfile    = "query2plot.log";

#
#  Redirect STDERR to STDOUT.
#
open (STDERR, ">&STDOUT" );

#
#  Get command line arguments, convert times to SFOC format.
#
$starttime = shift @ARGV;
$starttime =~ s/-/\//g;
$starttime =~ s/T/-/g;
$stoptime = shift @ARGV;
$stoptime =~ s/-/\//g;
$stoptime =~ s/T/-/g;
$rawdata = shift @ARGV;

#
#  Create temporary PVL file.
#
open ( PVL, ">$pvlfile" ) || die "\nERROR: $scriptname: Cannot open temporary PVL $pvlfile.\n\n";

print PVL <<"EndOfTemplateText";
OBJECT = 'ATT_TLM_Query';
   DESCRIPTION = 'Tot Query';
   REQUESTER_NAME = bsemenov;
   MISSION_NAME = Cas;
   SPACECRAFT_NAME = Cassini;
   DATA_FROM = { NERT } ;
   TIME_RANGE = { $starttime .. $stoptime } SCET;
   TIME_ORDER = SCET;
   GROUP = CHANNEL ;
      CHANNEL_SET = {A-1001,A-1002,A-1003,A-1004,A-1005,A-1006,A-1007};
      SAMPLE_MODE = ON_SAMPLE;
      DSS_ID = ALL ;
      WSE_FILTER = "virtual_channel_id=D0";
   END_GROUP = CHANNEL;
END_OBJECT = 'ATT_TLM_Query';
EndOfTemplateText

close ( PVL );

#
#  Create temporary channel set file.
#
open ( CHSET, ">$chsfile" ) || die "\nERROR: $scriptname: Cannot open temporary channel set file $chsfile.\n\n";

print CHSET <<"EndOfCHSETText";
A-1001 SCET EU
A-1002 SCET EU
A-1003 SCET EU
A-1004 SCET EU
A-1005 SCET EU
A-1006 SCET EU
A-1007 SCET EU
EndOfCHSETText

close ( CHSET );

#
#  Run query2plot.
#
$cmd = "query2plot -s 82 -q $tds -f $pvlfile -K $rawdata $chsfile 2>&1 >$logfile";
$result = `$cmd`;

#
#  Check for 'no data' in the log file.
#
$cmd = "grep -i ' NO DATA ' $logfile";
$nodata = `$cmd`;
if ( $nodata ne "" ) {
   die "\nERROR: $scriptname: $nodata\n\n";
}

#
#  Check for error in the log file.
#
$cmd = "grep -i error $logfile";
$logerrors = `$cmd`;
( $logerrors eq "" ) || die "\nERROR: ".
      "$scriptname: TDS query completed with errors. ".
      "See $logfile files for diagnostics.\n\n";

#
#  Finished OK.
#
print "\n$scriptname finished successfully.\n";
exit;
