#!/usr/bin/perl
#
#  This script runs MSOPCK to create CK file from parsed quaternions.
#
#  Usage:
#
#     > <this_script_name> <parsed_quats_file> <ck_file>
#
$scriptname = "cas_make_sc_ck.pl";
$version    = "1.0.0, February 12, 2000, BVS, NAIF/JPL";

#
#  Setups:
#
#     -- temporary MSOPCK setup file name;
#     -- temporary CK comments file name;
#
$setupfile  = "msopck.setup";
$commntfile = "msopck.cassini.comments";

#
#  Command line arguments.
#
$parseddata = shift @ARGV;
$ckfile = shift @ARGV;

#
#  Create SETUP file.
#
open ( SETUP, ">$setupfile" ) ||
      die "\nERROR: $scriptname: Cannot open temporary setup file ".
          "$setupfile for write.\n\n";
print SETUP <<"EndOfTemplateText";

\\begindata

LSK_FILE_NAME           = '/kernels/gen/lsk/naif0007.tls'
SCLK_FILE_NAME          = '/kernels/cassini/sclk/cassini.tsc'

INTERNAL_FILE_NAME      = 'TLM-BASED CAS S/C CK'
COMMENTS_FILE_NAME      = '$commntfile'

CK_TYPE                 = 3
CK_SEGMENT_ID           = 'TLM-BASED CASSINI S/C ATTITUDE'
INSTRUMENT_ID           = -82000
REFERENCE_FRAME_NAME    = 'J2000'
ANGULAR_RATE_PRESENT    = 'YES'

QUATERNION_NORM_ERROR   = 1.0e-3
ANGULAR_RATE_THRESHOLD  = ( 0.01745329, 0.01745329, 0.01745329 )
MAXIMUM_VALID_INTERVAL  = 16

INPUT_TIME_TYPE         = 'SCLK'
INPUT_DATA_TYPE         = 'MSOP QUATERNIONS'
ANGULAR_RATE_FRAME      = 'INSTRUMENT'

PRODUCER_ID             = 'Boris Semenov, NAIF/JPL'

\\begintext

EndOfTemplateText
close ( SETUP );

#
#  Create comments file.
#
$date = `date`;
chop( $date );
open ( COMMNT, ">$commntfile" ) ||
      die "\nERROR: $scriptname: Cannot open temporary comments file ".
          "$commntfile for write.\n\n";
print COMMNT <<"EndOfTemplateText";

Cassini Spacecraft Orientation CK File
===========================================================================


Orientation Data in the File
--------------------------------------------------------

     This file contains orientation and angular velocity data for the Cassini
     spacecraft frame, 'CASSINI_SC_COORD', relative to the Earth equator
     and equinox of J2000 inertial frame, 'J2000'. The NAIF ID code for
     the 'CASSINI_SC_COORD' frame is -82000.


Status
--------------------------------------------------------

     This file is a regular operational reconstructed C-Kernel file created
     by NAIF, which can be used for spacecraft operations and science data
     processing support by all project science and engineering teams.


Pedigree
--------------------------------------------------------

     This file was generated by an automated process. This process extracts
     spacecraft orientation quaternions and angular rates computed on-board
     from Cassini Telemetry Data System (TDS) and writes them to a CK file
     using MSOPCK program.


Approximate Time Coverage
--------------------------------------------------------

     This file is a type 3 CK file (segment) which provides linear
     interpolation between orientation data points extracted from
     telemetry. Such interpolation is not applied to the whole coverage of
     the file (segment) but only inside intervals where enough orientation
     telemetry data was available and orientation data points were close to
     each other in time for such interpolation to make sense.

     A table containing the complete list of valid interpolation intervals
     in the file is provided at the end of these comments.

     The start time and stop time of the total coverage for every segment
     in the file are given in the header of the intervals table for that
     segment.


Usage Note
--------------------------------------------------------

     In order to use this file a Cassini SCLK file, containing coefficients
     mapping Cassini on-board time to ET, and standard LSK file, providing UTC
     to ET mapping, must be loaded into a user's program.


Contacts
--------------------------------------------------------

     If you have any question regarding this data contact NAIF at JPL:

        Boris V. Semenov
        (818)-354-8136
        boris.semenov\@jpl.nasa.gov

EndOfTemplateText
close ( COMMNT );

#
#  Run msopck.
#
$cmd = "msopck $setupfile $parseddata $ckfile 2>&1";
$result = `$cmd`;
$status = ( $? >> 8 );

#
#  Check status and errors in msopck output.
#
if ( $status || $result =~ /^SPICE\(\w+\)$/ ){
   die "\nERROR: $scriptname: msopck completed with errors. The  ".
      "program output was as follows:\n$result\n\n";
}

#
#  Finished OK.
#
print "\n$scriptname finished successfully.\n";
exit;
